<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'Gwarezadur ar forum ouzh argadennoù evel cross-site scripting',
	'safehtml_slogan' => 'Gwarezadur ar forum ouzh ar cross-site scripting',
];
